@@ -30,6 +30,7 @@ from soco_cli.utils import (
     local_speaker_list,
     save_readline_history,
     set_interactive,
+    set_single_keystroke,
     set_suspend_sighandling,
     speaker_cache,
     version,
@@ -108,6 +109,7 @@ def interactive_loop(
     print("\nEntering SoCo-CLI interactive shell.")
     if single_keystroke:
         print("Single Keystroke Mode ... 'x' to exit.\n")
+        set_single_keystroke(True)
     else:
         print("Type 'help' for available shell commands.\n")
     if not RL:
@@ -134,19 +136,27 @@ def interactive_loop(
             else:
                 prompt = root_prompt + " [] > "
 
+            # Single keystroke input handling
             if single_keystroke:
                 prompt = prompt.replace(">", ">>")
                 print(prompt, flush=True, end="")
                 command_line = get_keystroke()
+                # Handle Windows CTRL-C; disable exit
+                if command_line == "\x03":
+                    logging.info("Windows CTRL-C received ... prevent exit")
+                    print("Please use 'x' to exit >> ")
+                    continue
                 print(command_line)
-                # Catch exit, including Windows CTRL-C
-                if command_line in ["x", "\x03"]:
+                # Normal exit
+                if command_line in ["x", "X"]:
                     logging.info("Exit from single keystroke mode")
                     single_keystroke = False
+                    set_single_keystroke(False)
                     continue
+
+            # Normal input handling
             else:
                 command_line = input(prompt)
-
             if command_line == "":
                 continue
 
@@ -207,6 +217,7 @@ def interactive_loop(
                 if command_lower in ["single-keystroke", "sk"]:
                     print("Single keystroke mode ... 'x' to exit")
                     single_keystroke = True
+                    set_single_keystroke(True)
                     continue
 
                 if command_lower == "speakers":
@@ -484,8 +495,8 @@ def interactive_loop(
                     print("Error: Invalid command")
 
         # Catch all exceptions in the interactive loop
-        except Exception as e:
-            print("Error: {}".format(e))
+        except:
+            continue
 
 
 COMMANDS = [
