@@ -4,6 +4,7 @@ import datetime
 import logging
 import os
 import pickle
+import signal
 
 try:
     import readline
@@ -36,6 +37,7 @@ def event_unsubscribe(sub):
 
 INTERACTIVE = False
 API = False
+SINGLE_KEYSTROKE = False
 
 
 def set_interactive():
@@ -48,12 +50,18 @@ def set_api():
     API = True
 
 
+def set_single_keystroke(sk):
+    global SINGLE_KEYSTROKE
+    SINGLE_KEYSTROKE = sk
+
+
 # Error handling
 def error_report(msg):
     # Print to stderr
     print("Error:", msg, file=sys.stderr, flush=True)
     # Use os._exit() to avoid the catch-all 'except'
     if not (INTERACTIVE or API):
+        logging.info("Exiting program using os._exit(1)")
         os._exit(1)
 
 
@@ -247,7 +255,7 @@ suspend_sighandling = False
 
 def set_suspend_sighandling(suspend=True):
     global suspend_sighandling
-    logging.info("Setting 'suspend_sigterm' to '{}'".format(suspend))
+    logging.info("Setting 'suspend_sighandling' to '{}'".format(suspend))
     suspend_sighandling = suspend
 
 
@@ -258,9 +266,11 @@ speaker_playing_local_file = None
 def set_speaker_playing_local_file(speaker):
     global speaker_playing_local_file
     if speaker:
-        logging.info("Speaker playing local file = '{}'".format(speaker.player_name))
+        logging.info(
+            "Setting speaker playing local file to '{}'".format(speaker.player_name)
+        )
     else:
-        logging.info("Speaker playing local file = 'None'")
+        logging.info("No speaker playing local file")
     speaker_playing_local_file = speaker
 
 
@@ -277,9 +287,28 @@ def sig_handler(signal_received, frame):
     sys.stdout = sys.__stdout__
     sys.stderr = sys.__stderr__
 
-    if INTERACTIVE:
-        print("Please use 'exit' to terminate the shell > ", end="", flush=True)
-        return
+    # Prevent SIGINT (CTRL-C) exit: untidy exit from readline can leave
+    # some terminals in a broken state
+    if signal_received == signal.SIGINT:
+        if SINGLE_KEYSTROKE:
+            logging.info("SINGLE_KEYSTROKE set ... preventing exit")
+            print("\nPlease use 'x' to exit >> ", end="", flush=True)
+            return
+
+        if INTERACTIVE:
+            logging.info("INTERACTIVE set ... preventing exit")
+            print("\nPlease use 'exit' to terminate the shell > ", end="", flush=True)
+            if os.name == "nt":
+                print(flush=True)
+            return
+
+    # Allow SIGTERM termination, but issue warning
+    if signal_received == signal.SIGTERM:
+        print("\nSoCo-CLI process terminating ...", flush=True)
+        print(
+            "This can leave some terminals in a misconfigured state.",
+            flush=True,
+        )
 
     if speaker_playing_local_file:
         logging.info(
@@ -289,11 +318,11 @@ def sig_handler(signal_received, frame):
         )
         speaker_playing_local_file.stop()
 
-    logging.info("Cleaning up event subscriptions")
+    logging.info("Unsubscribing from event notifications")
     unsub_all_remembered_event_subs()
 
     print("", flush=True)
-    logging.info("Exiting program using 'os_exit(0)'")
+    logging.info("Exiting program using 'os._exit(0)'")
     os._exit(0)
 
 
